@@ -1,4 +1,4 @@
-"join.freq" <-
+`join.freq` <-
 function(breaks,join){
 join<-join[-1]
 breaks<-breaks[-join]
